##########################################################################
# create_ccm_package.py
# or "10 Create CCM Package" tool in the CCM Flow toolbox
#
# By Michael Bunn, Ben Leshchinsky, and Michael Olsen
# Oregon State University
# Last Updated: 07/11/2018
#
# Creation of this tool has been supported by Oregon Department of
# Transportation research project SPR 786 and
# United States Forest Service grant number 17-CS-11015600-008
#
# Direct questions to ben.leshchinsky@oregonstate.edu
##########################################################################

# Import arcpy module
import arcpy, os
from arcpy.sa import *
arcpy.env.overwriteOutput=True
arcpy.CheckOutExtension("spatial")

# Get inputs
ThinPoly = arcpy.GetParameterAsText(0)

# Find location of input
descInput = arcpy.Describe(ThinPoly)
arcpy.env.workspace = os.path.dirname(descInput.catalogPath)

# Display output location
loc = arcpy.env.workspace
commentval = "Outputs will be saved to "+loc
arcpy.AddMessage(commentval)

# Create candidates layer
arcpy.MakeFeatureLayer_management(ThinPoly, "polyline")

# Check if Id field exists in candidates. If not, create it
check = 0
lst = arcpy.ListFields("polyline")
for f in lst:
    if f.name == "Id":
        check = 1
    else:
        continue
if check == 0:
    arcpy.AddField_management("polyline", "Id", "LONG")

# Assign a value of 1 to all candidates
try:
	arcpy.CalculateField_management("polyline", "Id", "[FID]")
except:
	try:
		arcpy.CalculateField_management("polyline", "Id", "[OBJECTID]")
	except:
		try:
			arcpy.CalculateField_management("polyline", "Id", "[OID]")
		except:
			acrpy.AddError("Scarp file does not have FID or OBJECTID field")

inputDEM = arcpy.GetParameterAsText(1)
method = arcpy.GetParameterAsText(2)
if method == 'Manual':
	mextn = 'Manual'
elif method == 'Semi-Automated':
	mextn = 'SemiAuto'
elif method == 'Automated':
	mextn = 'Auto'
else:
	mextn = 'CCM'

projdir = arcpy.GetParameterAsText(3)
if projdir == '#' or not projdir:
	projdir = os.path.dirname(arcpy.env.workspace)



# Ask user for elevation raster
inputDEM = arcpy.GetParameterAsText(1)

## Create CCM Input Package
# Identify project folder
idx = ThinPoly.find("CS")
foldir = mextn+"_Package_"+ThinPoly[idx:]
newdir = projdir+"\\"+foldir
exis = 1
errval = 0
orgdir = newdir
dir1 = newdir+str(1)
dir2 = newdir+str(2)
dir3 = newdir+str(3)

try:
	os.mkdir(newdir)
	exis = 0
except:
	error_mess = 'CCM Project "'+newdir+'" already exists. Use the "Output Folder" option to choose a new location to save'
	arcpy.AddError(error_mess)
		# if newdir == dir1:
			# newdir = orgdir
		# elif newdir == dir2:
			# newdir = orgdir
		# elif newdir == dir3:
			# newdir = orgdir
			
		# errval = errval+1
		# newdir = newdir+str(errval)
		# try:
			# arcpy.AddMessage(newdir)
			# os.mkdir(newdir)
			# exis = 0
		# except:
			# exis = 1


copyrast = newdir + "\\" + "CCM_DEM.tif"
copyscarp = newdir + "\\" + "CCM_scarps.shp"
# Interpolate DEM to polylines to create polylineZ
try:
	arcpy.CheckOutExtension("3D")
	arcpy.InterpolateShape_3d(inputDEM, ThinPoly, copyscarp)
except:
	arcpy.AddMessage("3D Analyst Extension Unavailable")
arcpy.CopyRaster_management(inputDEM,copyrast)
arcpy.Delete_management("polyline")

arcpy.CheckInExtension("spatial")