###################################################################
# select_DEM_resolution.py
# or "03 Find Cell Size for Mapping" tool in the SICCM toolbox
#
# By Michael Bunn, Ben Leshchinsky, and Michael Olsen
# Oregon State University
# Last Updated: 07/11/2018
#
# Creation of this tool has been supported by Oregon Department of
# Transportation research project SPR 786 and
# United States Forest Service grant number 17-CS-11015600-008
#
# Direct questions to ben.leshchinsky@oregonstate.edu
###################################################################
import arcpy, os
from arcpy.sa import *
arcpy.env.overwriteOutput = True
arcpy.CheckOutExtension('Spatial')

# Ask user for input DEM
input_raster = arcpy.GetParameterAsText(0)

# Find location of input
descInput = arcpy.Describe(input_raster)
arcpy.env.workspace = os.path.dirname(descInput.catalogPath)

# Display output location
loc = arcpy.env.workspace
commentval = "Outputs will be saved to "+loc
arcpy.AddMessage(commentval)

# Determine cellsize and unit of input DEM
description = arcpy.Describe(input_raster)
cellsize = description.children[0].meanCellHeight

spat = arcpy.Describe(input_raster).spatialReference
unit = spat.linearUnitName

### BEGIN DISPLAY PREPARATIONS ###

# Set the map document and data frame
mxd = arcpy.mapping.MapDocument("CURRENT")
df = arcpy.mapping.ListDataFrames(mxd,"Layers")[0]

# Find location of layer file
lyrDir = os.path.dirname(__file__)
lyrFile = lyrDir+"\\slope.lyr"

### END DISPLAY PREPARATIONS ###

# Ask user if they would like to perform default first run
RunDefaults = arcpy.GetParameterAsText(1)

# Compute first run, if desired
if RunDefaults == "true":

	# Loop through default values
	DefRes = [3, 6, 9]
	for ResVal in DefRes:
		# Prepare variable names for computations
		res = str(int(round(ResVal*cellsize)))
		SlopeRes = "Slope_" + res + unit
		cell = res + " " + res
		ResampleDEM = "Temp_RS"
		
		# Resample DEM and compute slope
		arcpy.Resample_management(input_raster, ResampleDEM, cell, "BILINEAR")
		OS = Slope(ResampleDEM, "DEGREE", "1")
		OS.save(SlopeRes)
		
		# Delete resampled DEM
		arcpy.Delete_management(ResampleDEM, "")

		# Display slope raster on map
		lyr = arcpy.mapping.Layer(SlopeRes)
		arcpy.ApplySymbologyFromLayer_management(lyr, lyrFile)
		arcpy.mapping.AddLayer(df,lyr)
		
		# Delete layer to prepare for next loop
		arcpy.Delete_management(lyr)

# Get custom cell sizes
CustomRes = arcpy.GetParameter(2)

for ResVal in CustomRes:
	# Prepare variable names for computations
	res = str(int(round(ResVal)))
	SlopeRes = "Slope_" + res + unit
	cell = res + " " + res
	ResampleDEM = "Temp_RS"
	
	# Resample DEM and compute slope
	arcpy.Resample_management(input_raster, ResampleDEM, cell, "BILINEAR")
	OS = Slope(ResampleDEM, "DEGREE", "1")
	OS.save(SlopeRes)
	
	# Delete resampled DEM
	arcpy.Delete_management(ResampleDEM, "")

	# Display slope raster on map
	lyr = arcpy.mapping.Layer(SlopeRes)
	arcpy.ApplySymbologyFromLayer_management(lyr, lyrFile)
	arcpy.mapping.AddLayer(df,lyr)
	
	# Delete layer to prepare for next loop
	arcpy.Delete_management(lyr)

arcpy.CheckInExtension('Spatial')

