##########################################################################
# thin_to_lines.py
# or "09 Create Scarp Lines from Scarp Polygons" tool in the CCM Flow toolbox
#
# By Michael Bunn, Ben Leshchinsky, and Michael Olsen
# Oregon State University
# Last Updated: 07/17/2018
#
# Creation of this tool has been supported by Oregon Department of
# Transportation research project SPR 786 and
# United States Forest Service grant number 17-CS-11015600-008
#
# Direct questions to ben.leshchinsky@oregonstate.edu
##########################################################################

# Import arcpy module
import arcpy, os
from arcpy.sa import *
arcpy.env.overwriteOutput=True
arcpy.CheckOutExtension("spatial")

# Ask user for candidates shapefile
Candidates = arcpy.GetParameterAsText(0)

# Find location of input
descInput = arcpy.Describe(Candidates)
arcpy.env.workspace = os.path.dirname(descInput.catalogPath)

# Find linear unit
spat = arcpy.Describe(Candidates).spatialReference
unit = spat.linearUnitName

# Display output location
loc = arcpy.env.workspace
commentval = "Outputs will be saved to "+loc
arcpy.AddMessage(commentval)

# Assign name to scarp line file
idx = Candidates.find("CS")
idx2 = Candidates.find("_MT")

extn = Candidates[idx:]
extn2 = Candidates[idx:idx2]

Scarps = "Scarps_"+extn

# Find cellsize of input DEM
cellsize = arcpy.GetParameterAsText(1)
if cellsize == '#' or not cellsize:
	mixture = "Mix_"+extn2
	description = arcpy.Describe(mixture)
	res = description.children[0].meanCellHeight
	cellsize = str(int(round(res)))
	
	cs_mess = "Cell size of mixture was: "+cellsize
	arcpy.AddMessage(cs_mess)
	



# Assign temporary variables
CandRast = "CandRast"
ThinRast = "ThinRast"

# Convert candidates into raster
arcpy.PolygonToRaster_conversion(Candidates, "LS", CandRast, "", "", cellsize)

# Thin raster candidates into lines
thinOut = Thin(CandRast)
thinOut.save(ThinRast)

# Convert raster lines to vector polylines
arcpy.RasterToPolyline_conversion(ThinRast, Scarps, "", "", "SIMPLIFY", "VALUE")


# # Interpolate DEM to polylines to create polylineZ
# try:
    # arcpy.CheckOutExtension("3D")
    # arcpy.InterpolateShape_3d(inputDEM, ThinPoly, Scarps)
# except:
    # arcpy.AddMessage("3D Analyst Extension Unavailable")

# Create candidates layer
arcpy.MakeFeatureLayer_management(Scarps, "scarps")



# Delete temporary variables
arcpy.Delete_management(CandRast)
arcpy.Delete_management(ThinRast)
arcpy.Delete_management("scarps")


## Display scarps on map

lyrDir = os.path.dirname(__file__)
fileScarp = lyrDir+"\\scarps.lyr"

# Set the map document and data frame
mxd = arcpy.mapping.MapDocument("CURRENT")
df = arcpy.mapping.ListDataFrames(mxd,"Layers")[0]

# Create layer file and add to map
lyrScarp = arcpy.mapping.Layer(Scarps)
arcpy.ApplySymbologyFromLayer_management(lyrScarp, fileScarp)
try:
	arcpy.mapping.RemoveLayer(df, arcpy.mapping.ListLayers(mxd, lyrScarp)[0])
	arcpy.mapping.AddLayer(df,lyrScarp)
except:
	arcpy.mapping.AddLayer(df,lyrScarp)


arcpy.CheckInExtension("spatial")

    
